@@ -1,11 +1,10 @@
 package Test::Data::Function;
 use strict;
 
-use base qw(Exporter);
-use vars qw(@EXPORT $VERSION);
+use Exporter qw(import);
 
-@EXPORT  = qw(prototype_ok);
-$VERSION = '1.24';
+our @EXPORT  = qw(prototype_ok);
+our $VERSION = '1.241';
 
 use Test::Builder;
 my $Test = Test::Builder->new();
@@ -32,8 +31,7 @@ This module provides test functions for subroutine sorts of things.
 
 =cut
 
-sub prototype_ok(\&$;$)
-	{
+sub prototype_ok(\&$;$) {
 	my $sub        = shift;
 	my $prototype  = shift;
 	my $name       = shift || 'function prototype is correct';
@@ -41,13 +39,11 @@ sub prototype_ok(\&$;$)
 	my $actual     = prototype( $sub );
 	my $test       = $actual eq $prototype;
 
-	unless( $test )
-		{
+	unless( $test ) {
 		$Test->diag( "Subroutine has prototype [$actual]; expected [$prototype]" );
 		$Test->ok(0, $name);
 		}
-	else
-		{
+	else {
 		$Test->ok( $test, $name );
 		}
 	}
@@ -75,7 +71,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2012 brian d foy.  All rights reserved.
+Copyright © 2002-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
